pub struct ExecutionContext { /* private fields */ }Expand description
ExecutionContext is intentionally opaque to non-adapter callers. Its internals are owned by the runtime and are not constructible outside this crate to satisfy CXT-1.
ⓘ
use ergo_adapter::ExecutionContext;
use ergo_runtime::runtime::ExecutionContext as RuntimeExecutionContext;
// Constructor is not visible outside ergo-adapter.
let runtime_ctx = RuntimeExecutionContext::default();
let _ctx = ExecutionContext::new(runtime_ctx);ⓘ
use ergo_adapter::ExecutionContext;
use ergo_runtime::runtime::ExecutionContext as RuntimeExecutionContext;
// Opaque fields cannot be set directly.
let runtime_ctx = RuntimeExecutionContext::default();
let _ctx = ExecutionContext { inner: runtime_ctx };Trait Implementations
Sourceimpl Clone for ExecutionContext
impl Clone for ExecutionContext
Sourcefn clone(&self) -> ExecutionContext
fn clone(&self) -> ExecutionContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ExecutionContext
impl RefUnwindSafe for ExecutionContext
impl Send for ExecutionContext
impl Sync for ExecutionContext
impl Unpin for ExecutionContext
impl UnsafeUnpin for ExecutionContext
impl UnwindSafe for ExecutionContext