pub struct RuntimeHandle { /* private fields */ }Expand description
RuntimeHandle holds the execution dependencies needed to invoke the runtime. It is constructed with an expanded graph, primitive catalog, registries, and adapter provides.
Implementations
Sourceimpl RuntimeHandle
impl RuntimeHandle
pub fn new( graph: Arc<ExpandedGraph>, catalog: Arc<CorePrimitiveCatalog>, registries: Arc<CoreRegistries>, adapter_provides: AdapterProvides, ) -> Self
pub fn run( &self, graph_id: &GraphId, event_id: &EventId, ctx: &ExecutionContext, deadline: Option<Duration>, ) -> RunTermination
Sourcepub fn graph_emittable_effect_kinds(&self) -> HashSet<String>
pub fn graph_emittable_effect_kinds(&self) -> HashSet<String>
Derive effect kinds that this composed graph can emit based on registered action manifests.